==> helidon-inject-api-4.0.3-sources.jar: io/helidon/inject/api/MetricsBlueprint.java <==
/*
 * Copyright (c) 2022, 2023 Oracle and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.helidon.inject.api;

import java.util.Optional;

import io.helidon.builder.api.Prototype;

/**
 * Metrics.
 */
@Prototype.Blueprint
interface MetricsBlueprint {

    /**
     * The total service count in the registry.
     *
     * @return total service count
     */
    Optional<Integer> serviceCount();

    /**
     * The total number of {@code Services::lookup()} calls since jvm start, or since last reset.
     *
     * @return lookup count
     */
    Optional<Integer> lookupCount();

    /**
     * The total number of {@code Services::lookup()} calls that were attempted against the lookup cache. This will be empty
     * if caching is disabled.
     *
     * @see InjectionServicesConfig
     * @return cache lookup count
     */
    Optional<Integer> cacheLookupCount();

    /**
     * The total number of {@code Services:lookup()} calls that were successfully resolved via cache. This will be a value less
     * than or equal to {@link #cacheLookupCount()}.
     *
     * @return cache hit count
     */
    Optional<Integer> cacheHitCount();

}

==> helidon-inject-api-4.0.10-sources.jar: io/helidon/inject/api/MetricsBlueprint.java <==
/*
 * Copyright (c) 2022, 2024 Oracle and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.helidon.inject.api;

import java.util.Optional;

import io.helidon.builder.api.Prototype;

/**
 * Metrics.
 * @deprecated Helidon inject is deprecated and will be replaced in a future version
 */
@Deprecated(forRemoval = true, since = "4.0.8")
@Prototype.Blueprint
interface MetricsBlueprint {

    /**
     * The total service count in the registry.
     *
     * @return total service count
     */
    Optional<Integer> serviceCount();

    /**
     * The total number of {@code Services::lookup()} calls since jvm start, or since last reset.
     *
     * @return lookup count
     */
    Optional<Integer> lookupCount();

    /**
     * The total number of {@code Services::lookup()} calls that were attempted against the lookup cache. This will be empty
     * if caching is disabled.
     *
     * @see InjectionServicesConfig
     * @return cache lookup count
     */
    Optional<Integer> cacheLookupCount();

    /**
     * The total number of {@code Services:lookup()} calls that were successfully resolved via cache. This will be a value less
     * than or equal to {@link #cacheLookupCount()}.
     *
     * @return cache hit count
     */
    Optional<Integer> cacheHitCount();

}
